@@ -94,12 +94,12 @@ class TabularClassifier(Algo, ABC):
         pass
 
     @abstractmethod
-    def dimensionality(self):
+    def is_multioutput(self):
         """
-        Describes the dimensionality of the targets the estimator supports.
+        Returns true if the estimator supports mulitple outputs.
         
         Returns: 
-            Dimensionality.
+            Boolean.
         """
         pass
 
@@ -145,12 +145,12 @@ class TabularRegressor(Algo, ABC):
         pass
 
     @abstractmethod
-    def dimensionality(self):
+    def is_multioutput(self):
         """
-        Describes the dimensionality of the targets the estimator supports.
-
+        Returns true if the estimator supports mulitple outputs.
+        
         Returns: 
-            Dimensionality.
+            Boolean.
         """
         pass
 
