@@ -10,12 +10,9 @@ import datetime
 from .errors import TestError
 from .targets import create_classification_target, create_regression_target
 from ..base.tabular import TabularClassifier, TabularRegressor, is_input_metatype
-from ..base.types import Dimensionality, Metatype, is_dimensionality, is_classification_metatype, is_delimiter_metatype, get_delimiter
+from ..base.types import Metatype, is_classification_metatype, is_delimiter_metatype, get_delimiter
 from ..metrics.metrics import get_metric
 
-{Metatype.NUMERICAL, Metatype.CATEGORICAL, Metatype.BINARY,
-            Metatype.DATETIME, Metatype.TIMESTAMP, Metatype.DELIM_PIPE, Metatype.DELIM_SEMICOLON}
-
 def create_tabular_inputs(input_metatypes, n_rows = 1000, n_cols = 2, seed = 0):
     X_metatypes = []
     data = []
@@ -57,15 +54,15 @@ def load_tabular_data(algo, nan_fraction = 0.1):
     rng = np.random.default_rng(seed = 0)
     X.mask(rng.uniform(size = X.shape) < nan_fraction, inplace=True)
 
-    dimensionality = algo.dimensionality()
-    if not is_dimensionality(dimensionality, strict = True):
-        raise TestError('invalid dimensionality')
+    is_multioutput = algo.is_multioutput()
+    if not isinstance(is_multioutput, bool):
+        raise TestError('is_multioutput should return bool')
 
-    n_cols = 1 if dimensionality == Dimensionality.UNIVARIATE else 3
+    n_cols = 3 if is_multioutput else 1
 
     if isinstance(algo, TabularClassifier):
         target_metatype = algo.target_metatype()
-        categories = ['bad', 'good'] if target_metatype == Metatype.BINARY else ['cat', 'dog', 'mouse', 'bird']
+        categories = ['bad', 'good'] if target_metatype == Metatype.BINARY else ['red', 'green', 'blue', 'yellow']
         y = create_classification_target(X.index, n_cols, categories)
         y_metatypes = [target_metatype for x in range(n_cols)]
     elif isinstance(algo, TabularRegressor):
@@ -87,13 +84,13 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
         if not is_input_metatype(metatype):
             raise TestError('invalid input metatype')
 
-    output['input_metatypes'] = sorted(list(input_metatypes))
+    output['input_metatypes'] = sorted(list(input_metatypes), key=lambda x: x.name)
 
-    dimensionality = algo.dimensionality()
-    if not is_dimensionality(dimensionality, strict = True):
-        raise TestError('invalid dimensionality')
+    is_multioutput = algo.is_multioutput()
+    if not isinstance(is_multioutput, bool):
+        raise TestError('is_multioutput should return bool')
 
-    output['dimensionality'] = dimensionality
+    output['is_multioutput'] = is_multioutput
 
     if isinstance(algo, TabularClassifier):
         target_metatype = algo.target_metatype()
@@ -131,7 +128,7 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
         for prediction_method in ('predict_proba', 'decision_function'):
             try:
                 pred_prediction_method = getattr(algo, prediction_method)(X)
-                if algo.dimensionality() == Dimensionality.UNIVARIATE:
+                if not algo.is_multioutput():
                     pred_prediction_method = [pred_prediction_method]
 
                 for ppm, col in zip(pred_prediction_method, y):
